==> tencent_cloud_chat_sdk-7.7.5314.tar.gz: example/lib/api/V2TIMManager/getUserStatus.dart <==
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:tencent_cloud_chat_sdk/enum/V2TimSDKListener.dart';
import 'package:tencent_cloud_chat_sdk/enum/log_level_enum.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_callback.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_friend_info.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_user_status.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_value_callback.dart';
import 'package:tencent_cloud_chat_sdk/tencent_im_sdk_plugin.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMManager/getUserStatus.dart';

class GetUserStatus extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _GetUserStatusState();
  }
}

class _GetUserStatusState extends State<GetUserStatus> {
  String result = '';
  List<String> friends = [];
  String selectedId = '';
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    result = '';
    getFriendList();
  }

  getFriendList() async {
    V2TimValueCallback<List<V2TimFriendInfo>> getFriendListRes =
        await TencentImSDKPlugin.v2TIMManager
            .getFriendshipManager()
            .getFriendList();

    if (getFriendListRes.code == 0) {
      getFriendListRes.data?.forEach((element) {
        friends.add(element.userID);
      });
    }
  }

  pressedFunction() async {
    if (selectedId == '') {
      return;
    }
    V2TimValueCallback<List<V2TimUserStatus>> loginRes =
        await TencentImSDKPlugin.v2TIMManager
            .getUserStatus(userIDList: [selectedId]);
    setState(() {
      result = loginRes.toJson().toString();
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        home: Scaffold(
      appBar: AppBar(
        leading: IconButton(
          onPressed: () => Navigator.pop(context),
          icon: Icon(Icons.arrow_back_ios),
        ),
        title: Text('getUserStatus'),
      ),
      body: Center(
        child: Column(
          children: [
            Row(
              children: [
                DropdownMenu<String>(
                    width: 200,
                    label: const Text('user id'),
                    onSelected: (String? id) {
                      print(id);
                      selectedId = id ?? '';
                    },
                    requestFocusOnTap: true,
                    dropdownMenuEntries:
                        friends.map<DropdownMenuEntry<String>>((String id) {
                      return DropdownMenuEntry<String>(
                        value: id,
                        label: id,
                      );
                    }).toList()),
                const SizedBox(
                  width: 20,
                ),
                ElevatedButton(
                  child: Text('getUserStatus'),
                  onPressed: () {
                    pressedFunction();
                  },
                ),
              ],
            ),
            const SizedBox(
              height: 20,
            ),
            Text(result)
          ],
        ),
      ),
    ));
  }
}

==> tencent_cloud_chat_sdk-7.8.5509.tar.gz: example/lib/api/V2TIMManager/getUserStatus.dart <==
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:tencent_cloud_chat_sdk/enum/V2TimSDKListener.dart';
import 'package:tencent_cloud_chat_sdk/enum/log_level_enum.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_callback.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_friend_info.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_user_status.dart';
import 'package:tencent_cloud_chat_sdk/models/v2_tim_value_callback.dart';
import 'package:tencent_cloud_chat_sdk/tencent_im_sdk_plugin.dart';
import 'package:tencent_cloud_chat_sdk_example/api/V2TIMManager/getUserStatus.dart';

class GetUserStatus extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _GetUserStatusState();
  }
}

class _GetUserStatusState extends State<GetUserStatus> {
  String result = '';
  List<String> friends = [];
  String selectedId = '';
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    result = '';
    getFriendList();
  }

  getFriendList() async {
    V2TimValueCallback<List<V2TimFriendInfo>> getFriendListRes =
        await TencentImSDKPlugin.v2TIMManager
            .getFriendshipManager()
            .getFriendList();

    if (getFriendListRes.code == 0) {
      List<String> temp = [];
      getFriendListRes.data?.forEach((element) {
        temp.add(element.userID);
      });
      setState(() {
        friends = temp;
      });
    }
  }

  pressedFunction() async {
    if (selectedId == '') {
      return;
    }
    V2TimValueCallback<List<V2TimUserStatus>> loginRes =
        await TencentImSDKPlugin.v2TIMManager
            .getUserStatus(userIDList: [selectedId]);
    setState(() {
      result = loginRes.toJson().toString();
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        home: Scaffold(
      appBar: AppBar(
        leading: IconButton(
          onPressed: () => Navigator.pop(context),
          icon: Icon(Icons.arrow_back_ios),
        ),
        title: Text('getUserStatus'),
      ),
      body: Center(
        child: Column(
          children: [
            Row(
              children: [
                DropdownMenu<String>(
                    width: 200,
                    label: const Text('user id'),
                    onSelected: (String? id) {
                      print(id);
                      selectedId = id ?? '';
                    },
                    requestFocusOnTap: true,
                    dropdownMenuEntries:
                        friends.map<DropdownMenuEntry<String>>((String id) {
                      return DropdownMenuEntry<String>(
                        value: id,
                        label: id,
                      );
                    }).toList()),
                const SizedBox(
                  width: 20,
                ),
                ElevatedButton(
                  child: Text('getUserStatus'),
                  onPressed: () {
                    pressedFunction();
                  },
                ),
              ],
            ),
            const SizedBox(
              height: 20,
            ),
            Text(result)
          ],
        ),
      ),
    ));
  }
}
